@@ -24,9 +24,13 @@ from django.shortcuts import render_to_response, get_object_or_404
 from django.template import loader, Context, RequestContext
 from django.utils.translation import ugettext as _
 from django.utils.html import escape
-from django.utils import timezone
 from django import forms
 
+try:
+    from django.utils import timezone
+except ImportError:
+    from datetime import datetime as timezone
+
 from helpdesk.forms import TicketForm, UserSettingsForm, EmailIgnoreForm, EditTicketForm, TicketCCForm, EditFollowUpForm, TicketDependencyForm
 from helpdesk.lib import send_templated_mail, query_to_dict, apply_query, safe_template_context
 from helpdesk.models import Ticket, Queue, FollowUp, TicketChange, PreSetReply, Attachment, SavedSearch, IgnoreEmail, TicketCC, TicketDependency
@@ -488,15 +492,17 @@ def update_ticket(request, ticket_id, public=False):
         
 
         if f.new_status == Ticket.RESOLVED_STATUS:
-            template = 'resolved_submitter'
+            template = 'resolved_'
         elif f.new_status == Ticket.CLOSED_STATUS:
-            template = 'closed_submitter'
+            template = 'closed_'
         else:
-            template = 'updated_submitter'
+            template = 'updated_'
+
+        template_suffix = 'submitter'
 
         if ticket.submitter_email:
             send_templated_mail(
-                template,
+                template + template_suffix,
                 context,
                 recipients=ticket.submitter_email,
                 sender=ticket.queue.from_address,
@@ -505,10 +511,12 @@ def update_ticket(request, ticket_id, public=False):
                 )
             messages_sent_to.append(ticket.submitter_email)
 
+        template_suffix = 'cc'
+
         for cc in ticket.ticketcc_set.all():
             if cc.email_address not in messages_sent_to:
                 send_templated_mail(
-                    template,
+                    template + template_suffix,
                     context,
                     recipients=cc.email_address,
                     sender=ticket.queue.from_address,
